@@ -26,6 +26,25 @@ sub tmode
 	$tmode->execute() || die $dbh->errstr;
 }
 
+#
+# These are the error codes that mysql returns when it deadlocks or has
+# clashing transactions.
+#
+sub deadlock_rx
+{
+	return (
+		qr/Deadlock found when trying to get lock/,
+		qr/Deadlock found when trying to get lock; try restarting transaction/,
+		qr/Lock wait timeout exceeded; try restarting transaction/,
+		qr/:Duplicate entry/,
+	);
+}
+
+sub nodata_rx
+{
+	return qr/Table '\S+object' doesn't exist/;
+}
+
 sub initialize
 {
 	my $dbo = shift;
@@ -134,18 +153,11 @@ sub clean_query
 	my ($dbo, $query) = @_;
 	if ($query =~ /\bSELECT\b/i && ! $dbo->{readyonly}) {
 		$query =~ s/;//;
-		# $query .= " LOCK IN SHARE MODE";
-		# $query .= " FOR UPDATE";
 		if ($dbo->{mysql_for_update}) {
-			# great
-		} elsif (defined $dbo->{mysql_for_update}) {
-			$query .= " FOR UPDATE";
-		} else {
-			warn "dbo->mysql_for_update not defined";
-			$query .= " FOR UPDATE";
+			$query .= " FOR UPDATE"
+				unless $query =~ / FOR UPDATE\s*/;
 		}
 	}
-	1 while $query =~ s/  +/ /g;  # query log is easier to debug
 	return $dbo->SUPER::clean_query($query);
 }
 
@@ -238,5 +250,4 @@ sub byebye
 	$dbo->{counterdbh}->disconnect() if $dbo->{counterdbh};
 }
 
-
 1;
